#!/bin/bash
# configApp.sh
#===============================================================================================
# Spreader Report Configuration for All Spreaders
# This assumes that you already have a GPSReport configure for reporting GPSData.
#
# NOTE: Ensure that there is space available in the requested GPSReport to add in the PCYP message
#	( ie less than 4 have already been added ) when using gpsaddmes
#
#
# Also sets up the PCYP String
# ****** CONFIGURE SETTINGS HERE ****************
# To configure, run this file and send 2 paramaters One for Spreader, and the other for baudrate
# EG: sh /var/data/reports/scripts/config/configApp.sh CIRUS 9600
#===============================================================================================
# Specify Spreader settings, received from CCM install command
#
# These variables should not need to change
SPREADER_PCYP_STRING=1000			            # Set the PCYP id to use.
SPREADER=$1
BAUDRATE=$2
RESET=$3
#
#===============================================================================================

main () {
	echo "*** Started configApp ***"
	configSpreaderSpecific
	configSpreaderBasics
	cmd save
	echo "*** Completed configApp ***"
	return
}

configSpreaderBasics () {
	echo " Configuring Generic Spreader Settings"
# Enable reportscripts
	cmd reportscripts 1
# CTM-91 Disable mqtt to stop report from crashing on empty USR_STR
	cmd iot mqtt_enable 0

# vcc report linking to report100.sh (our start script)
	cmd vccreport 8 100
	cmd vcccond 8 2 8 30

# GPS report settings for vue
	cmd gpscond 8 2 30
	cmd gpsremip 8 cypressvue.com
	cmd gpsremport 8 8300
	cmd gpsrep 8 0 3 1 1 3000
	cmd gpsaddmes 8 114 1000
	

# Add spreader data/version to the PCYP Strings
	cmd pcyp msg add $SPREADER_PCYP_STRING USR_STR_1
	cmd pcyp msg add $SPREADER_PCYP_STRING USR_STR_2
	cmd pcyp msg add $SPREADER_PCYP_STRING USR_STR_3
	cmd pcyp msg add $SPREADER_PCYP_STRING USR_STR_4
	cmd pcyp msg add $SPREADER_PCYP_STRING USR_FLT_9
	
	echo " Generic Spreader Settings Applied"
	return
}


# 
#  $1 = SPREADER_TYPE
#  $2 = SPREADER_BAUD_RATE
configSpreaderSpecific () {
	echo " Validating and Configuring $SPREADER"
	if [[ $SPREADER == "EPOKE" ]]; then
		configEpoke
		echo ""
	elif [[ $SPREADER == "CS550" ]]; then
		configCS550
	elif [[ $SPREADER == "CIRUS" ]]; then
		configCirus
	else
		cmd event add SPREADER_NOT_DEFINED_LINE13_configApp.sh
		echo " FAILED: Spreader should be CIRUS/EPOKE/CS550, not $SPREADER "
		exit 1
	fi
	echo " $SPREADER Config Complete"
	return
}


configEpoke () {
# Port Settings
	cmd port 1 $BAUDRATE 8 n 1 0
	cmd mode 24 0
	
	cmd aux mode 0
	cmd aux datatype 0
	cmd aux leadlen 2
	cmd aux lead2len 0
	cmd aux leadmode 1
	cmd aux leadterm 2
	cmd aux len 0
	cmd aux dev EPO
	cmd aux polltim 0 1200 0
	cmd aux term 0D 0A
	cmd aux cond 1 0 0 0
	cmd aux termlen 2
	
	cmd event add EPOKE_SETTINGS_APPLIED
	checkReset
}


#  $1 = SPREADER_BAUD_RATE
# Setup the serial port and AUX details
configCS550 () {

	cmd port 1 $BAUDRATE 8 n 1 0
	cmd mode 23
	
	cmd aux mode 0
	cmd aux datatype 1
	cmd aux leadlen 2
	cmd aux lead2len 0
	cmd aux leadmode 1
	cmd aux leadterm 2
	cmd aux len 128
	cmd aux dev 550
	cmd aux polltim 2 400 0
	cmd aux term 0D 0A
	cmd reportscripts 1
	cmd aux cond 1 0 0 0
	cmd aux pollstr @1
	
	cmd event add CS550_INSTALL_OK
	checkReset
	return
}

#
configCirus () {
	cmd mode 0
	
	cmd event add Cirus_INSTALL_OK
	sleep 5
}

checkReset () {
	if [[ $RESET == "RESET" ]]; then
		source /var/data/reports/scripts/config/seasonalReset.sh SendSpreaderReset
	elif [[ $RESET == "KEEP" ]]; then
		return
	else
		echo " RESET Paramater Entered is incorrect. Value: $RESET"
	fi
	return
}

main
