#!/bin/bash
# Must link to vccreport 8
#
# Start/Monitor Script
#   Based on defined app, monitor scripts to make sure they are always running
# Single shot script, gets called again on vcccond approx every 30 seconds

INSTALL_DIR="/var/data/reports/scripts"

runSpreaders () {
	# This runs the functions required based on the App that is selected.
	# based on config, run correct spreader.
	CHECKMODE=$(cmd mode | grep "cmd mode" | awk -F " " '{print$3}')

	if [[ $CHECKMODE == "0" ]]; then
		checkRunCirus
		return
	elif [[ $CHECKMODE == "23" ]]; then
		loadNVData
		checkRunCS550
		backupNVData
		return
	elif [[ $CHECKMODE == "24" ]]; then
		loadNVData
		checkRunEpoke
		backupNVData
		return
	else
		return
	fi
}

backupNVData () {
# This function backs up data to NV for Epoke and CS550
# Monitors IGN state, and time.
# 
# If IGN = 0 backup data every 60 seconds till power off
# Else backup every 30 minutes
#
	if [ ! -e /tmp/SpreaderNVTimestamp ]
	then
		#write UTC timestamp of current time to file
		date +%s > /tmp/SpreaderNVTimestamp
		return
	else
		TIMENOW=$(date +%s)
		TIMEBEFORE=$(cat /tmp/SpreaderNVTimestamp)
		TIMEELAPSED=$(($TIMENOW - $TIMEBEFORE))
		IGNVALUE=$(cmd sysdb get VEH_IGN | grep VEH_IGN | awk -F "=" '{print$2}')
		if [ $IGNVALUE == 0 ]; then
			if [ $TIMEELAPSED -ge 5 ]; then
				cp /tmp/spreader_data.txt $INSTALL_DIR/seasonal_totals/
				cp /tmp/spreader_data.txt $INSTALL_DIR/seasonal_totals/spreader_data.bak.txt
				cp /tmp/spreader_data.crc $INSTALL_DIR/seasonal_totals/
				cp /tmp/spreader_data.crc $INSTALL_DIR/seasonal_totals/spreader_data.bak.crc

				date +%s > /tmp/SpreaderNVTimestamp
				logger "backupSeasonalTotals: IGN Low Detected, Data backed up"
				cmd event add SPREADER_SAVE_TO_NV_LPM
				return
			fi
		elif [ $IGNVALUE == 1 ]; then
			if [ $TIMEELAPSED -ge 1800 ]; then
				cp /tmp/spreader_data.txt $INSTALL_DIR/seasonal_totals/
				cp /tmp/spreader_data.txt $INSTALL_DIR/seasonal_totals/spreader_data.bak.txt
				cp /tmp/spreader_data.crc $INSTALL_DIR/scripts/seasonal_totals/
				cp /tmp/spreader_data.crc $INSTALL_DIR/seasonal_totals/spreader_data.bak.crc
				
				date +%s > /tmp/SpreaderNVTimestamp
				logger "backupSeasonalTotals: IGN High Detected, Data backed up after $TIMEELAPSED seconds"
				cmd event add SPREADER_SAVE_TO_NV_30
				return
			fi
		fi
	fi
}

loadNVData () {
#This function makes sure that the seasonal data is moved to /tmp so that the app can update the values.
	if [ -e /tmp/spreader_data.txt ] && [ -e /tmp/spreader_data.crc ]; then
		return
	elif [ -e $INSTALL_DIR/seasonal_totals/spreader_data.txt ] && [ -e $INSTALL_DIR/seasonal_totals/spreader_data.crc ]; then
		cp $INSTALL_DIR/seasonal_totals/* /tmp/
		logger "report100: Data copied from NV to tmp"
		cmd event add SPREADER_NV_SEASONALS_LOADED
		return
	else
		.$INSTALL_DIR/config/seasonalReset.sh SendSpreaderReset
		logger "report100: Seasonal reset complete"
		cmd event add Seasonal_Reset_Complete
		return
	fi
}

checkRunEpoke () {
# This function monitors Epoke to make sure it is running, It will run it if it is not
	result=`ps | grep runEpoke -c`
	if [ $result -eq 2 ]; then
		return
   	else
		$INSTALL_DIR/controller/runEpoke.sh &
		return
	fi
}

checkRunCirus () {
# This function monitors Cirus to make sure it is running, It will run it if it is not
	result=`ps | grep runCirus -c`
	if [ $result -eq 2 ]; then
		return
   	else
		$INSTALL_DIR/controller/runCirus.sh &
		return
	fi
}

checkRunCS550 () {
# This function monitors CS550 to make sure it is running, It will run it if it is not

	result=`ps | grep runCS550 -c`
	if [ $result -ge 2 ]; then
		return
   	else
		$INSTALL_DIR/controller/runCS550.sh &
		return
	fi
}


runSpreaders
